pecos.errors
============

.. automodule:: pecos.errors















   .. rubric:: Exceptions

   .. autosummary::

      MissingCCOPError
      NotSupportedGateError
      PECOSError
      WasmError
      WasmRuntimeError
